﻿$v2rayPID = Get-Process -name v2ray -ErrorAction Ignore | Select-Object id | ForEach-Object -Process { $_.id }
$wv2rayPID = Get-Process -name wv2ray -ErrorAction Ignore | Select-Object id | ForEach-Object -Process { $_.id }
$v2rayInstallPath = "$env:SystemDrive" + "\tools" + "\v2ray"
$temp = "$env:TEMP"
$urlia32 = "https://github.com/v2fly/v2ray-core/releases/download/v4.37.3/v2ray-windows-32.zip"
$urlarm32 = "https://github.com/v2fly/v2ray-core/releases/download/v4.37.3/v2ray-windows-arm32-v7a.zip"
$url64 = "https://github.com/v2fly/v2ray-core/releases/download/v4.37.3/v2ray-windows-64.zip"
$SHA256_ia32 = "d4f20c584efda7783b7009b69eaccdd279e89bff1c05e4b5552eb59efcf3a81b"
$SHA256_arm32 = "6681b73f7da3bb8b2e310c5897f7506dad58d0c1b5792c22804e47a11275839f"
$SHA256_64 = "a2cfe9229af74903752f5e34ca76f6368cf2c329ed2dea8d88d4bfce152d55f6"

# Check the device, is it an ARM-based one?
$CheckARM = Get-WmiObject win32_processor | Select-Object Caption | Select-String ARM

if ([String]::IsNullOrEmpty($CheckARM)) {
    $url = $urlia32; $SHA256_32 = $SHA256_ia32
}
else {
    Write-Output "You have an ARM-based Windows device, it is going to install armv7(AArch32) version for you.";
    $url = $urlarm32; $SHA256_32 = $SHA256_arm32
}

# Download and installation
Get-ChocolateyWebFile -PackageName "v2ray.zip" -FileFullPath "$temp\v2ray.zip"  -Url $url  -Checksum $SHA256_32 -ChecksumType 'sha256' -Url64 $url64  -Checksum64 $SHA256_64  -ChecksumType64 'sha256'
if ([String]::IsNullOrEmpty($v2rayPID)) {
    Write-Output "Process v2ray.exe is not running."
} 
else {
    Write-Output "Process v2ray.exe is running, stop it and install a new version."; Stop-Process $v2rayPID
}
if ([String]::IsNullOrEmpty($wv2rayPID)) {
    Write-Output "Process wv2ray.exe is not running."
} 
else {
    Write-Output "Process wv2ray.exe is running, stop it and install a new version."; Stop-Process $wv2rayPID
}
Install-ChocolateyZipPackage -PackageName 'v2ray'  -UnzipLocation $v2rayInstallPath -File $temp\v2ray.zip  -File64 $temp\v2ray.zip 
Install-ChocolateyPath -PathToInstall $v2rayInstallPath -PathType 'Machine'
Write-Output "V2Ray Core has been installed / updated, you can use it now."